# limit parallel builds on aarch64
%ifarch aarch64
%global _smp_ncpus_max 4
%endif

%define uversion 2019.05
%define version %(echo %{uversion} | tr '-' '.')

Name:           openscad
Version:        %{version}
Release:        %mkrel 10
Summary:        The Programmers Solid 3D CAD Modeller
# COPYING contains a linking exception for CGAL
# AppData is CC0
License:        GPLv2 with exceptions and CC0
Group:          Graphics/3D
URL:            http://www.openscad.org/
Source0:        http://files.openscad.org/%{name}-%{uversion}.src.tar.gz
Patch0:         openscad-polyclipping.patch
# Upstream backports:
# Crash with empty STL/PNG import
# https://github.com/openscad/openscad/issues/2965
Patch1:         https://github.com/openscad/openscad/pull/2973.patch
Patch2:         openscad-2019.05-include_stack.patch
Patch3:         openscad-boost-includes.patch
BuildRequires:  bison
BuildRequires:  boost-devel
BuildRequires:  cgal-devel
BuildRequires:  cmake
BuildRequires:  flex
BuildRequires:  imagemagick
BuildRequires:  gmp-devel
BuildRequires:  opencsg-devel
BuildRequires:  cmake(double-conversion)
BuildRequires:  pkgconfig(mpfr)
BuildRequires:  pkgconfig(eigen3)
BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(glew)
BuildRequires:  pkgconfig(harfbuzz)
BuildRequires:  pkgconfig(lib3MF)
BuildRequires:  pkgconfig(libxml-2.0)
BuildRequires:  pkgconfig(libzip)
BuildRequires:  pkgconfig(polyclipping)
BuildRequires:  pkgconfig(python3)
BuildRequires:  qscintilla-qt5-devel
BuildRequires:  pkgconfig(Qt5Concurrent)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gamepad)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  x11-server-xvfb

%description
OpenSCAD is a software for creating solid 3D CAD objects.
Unlike most free software for creating 3D models (such as the famous
application Blender) it does not focus on the artistic aspects of 3D
modeling but instead on the CAD aspects. Thus it might be the application
you are looking for when you are planning to create 3D models of machine
parts but pretty sure is not what you are looking for when you are more
interested in creating computer-animated movies.

%prep
%autosetup -p1 -n %{name}-%{uversion}

# Unbundle polyclipping
rm -rf src/ext/polyclipping

%build
%qmake_qt5 VERSION=%{uversion} \
           PREFIX=%{_prefix} \
           CONFIG-=debug
%make_build

# Build test suite
pushd tests
  cmake -DPYTHON_EXECUTABLE:STRING=%{__python3} .
  %make_build
popd

%install
%make_install INSTALL_ROOT=%{buildroot}

%check
# Run tests
pushd tests
  ctest %{?_smp_mflags} || : # let the tests fail, as some don't work on the BS
popd

%files
%doc COPYING README.md RELEASE_NOTES.md
%{_bindir}/%{name}
%{_metainfodir}/org.%{name}.OpenSCAD.appdata.xml
%{_datadir}/applications/%{name}.desktop
%{_datadir}/mime/packages/%{name}.xml
%{_datadir}/pixmaps/%{name}.png
%{_datadir}/%{name}/
%{_mandir}/man1/%{name}.1*


%changelog
* Thu Dec 31 2020 wally <wally> 2019.05-10.mga8
+ Revision: 1666796
- rebuild for boost 1.75.0

* Sun Dec 20 2020 wally <wally> 2019.05-9.mga8
+ Revision: 1662038
- rebuild for boost 1.74.0

* Thu Dec 17 2020 umeabot <umeabot> 2019.05-8.mga8
+ Revision: 1659219
- Rebuild for new Qt5

* Wed Dec 02 2020 luigiwalser <luigiwalser> 2019.05-7.mga8
+ Revision: 1651365
- rebuild for glew

* Sun May 03 2020 wally <wally> 2019.05-6.mga8
+ Revision: 1578453
- rebuild for boost 1.73.0

* Thu Feb 20 2020 umeabot <umeabot> 2019.05-5.mga8
+ Revision: 1545113
- Mageia 8 Mass Rebuild

* Mon Jan 27 2020 daviddavid <daviddavid> 2019.05-4.mga8
+ Revision: 1484067
- add patch to fix a crash with empty STL/PNG import
- add patch to fix missing header (include <stack>)
+ wally <wally>
- rebuild for boost 1.72.0

* Sat Jan 04 2020 daviddavid <daviddavid> 2019.05-3.mga8
+ Revision: 1476533
- enable lib3MF support

* Fri Jan 03 2020 daviddavid <daviddavid> 2019.05-2.mga8
+ Revision: 1475886
- new version: 2019.05
- switch tests to python3
- split out all Qt5 BRs and add a new one on Qt5Gamepad

* Sun Mar 31 2019 umeabot <umeabot> 2015.03.3-16.mga7
+ Revision: 1383648
- Qt5 Rebuild

* Tue Feb 19 2019 daviddavid <daviddavid> 2015.03.3-15.mga7
+ Revision: 1368523
- rebuild for new qscintilla 2.11.1

* Tue Oct 16 2018 wally <wally> 2015.03.3-14.mga7
+ Revision: 1321073
- rebuild for new boost 1.68.0

* Sun Sep 23 2018 umeabot <umeabot> 2015.03.3-13.mga7
+ Revision: 1300032
- Mageia 7 Mass Rebuild

* Thu Apr 19 2018 daviddavid <daviddavid> 2015.03.3-12.mga7
+ Revision: 1220179
- rebuild for new qscintilla 2.10.4

* Tue Feb 20 2018 kekepower <kekepower> 2015.03.3-11.mga7
+ Revision: 1203581
- Rebuild for new mpfr

* Tue Jan 23 2018 wally <wally> 2015.03.3-10.mga7
+ Revision: 1196621
- add patch from usptream to fix build with Qt > 5.7.1
- rebuild for new boost
+ tv <tv>
- rebuild for boost 1.65
- rebuild with latest boost
- rebuild for new libglew

* Tue Jan 31 2017 barjac <barjac> 2015.03.3-6.mga6
+ Revision: 1084308
- Rebuild for eigen3

* Sat Oct 29 2016 akien <akien> 2015.03.3-5.mga6
+ Revision: 1063912
- Rebuild for cgal 4.9

* Sun Sep 25 2016 akien <akien> 2015.03.3-4.mga6
+ Revision: 1055955
- Rebuild for polyclipping 6.4

* Sun Apr 24 2016 akien <akien> 2015.03.3-1.mga6
+ Revision: 1005908
- Version 2015.03-3

* Sun Feb 14 2016 joequant <joequant> 2015.03.2-4.mga6
+ Revision: 960315
- Work around flex build problem
  This works around the build problem in bug 1546 in the openscad github
  site.  The qtmake doesn't add a prefix arg for flex.
+ akien <akien>
- Disable debug build (upstream GH-1045)
- Use system polyclipping (Fedora patch)
+ daviddavid <daviddavid>
- rebuild for new boost 1.60.0

* Sun Dec 13 2015 akien <akien> 2015.03.2-1.mga6
+ Revision: 910083
- Version 2015.03-2

* Thu Oct 22 2015 ycantin <ycantin> 2015.03.1-6.mga6
+ Revision: 894247
- qt5 build
- rebuild for new boost
+ fwang <fwang>
- rebuild for new boost
+ tv <tv>
- rebuild for new boost

* Wed Sep 09 2015 fwang <fwang> 2015.03.1-3.mga6
+ Revision: 874670
- rebuild for new qscintilla

* Sun Aug 30 2015 akien <akien> 2015.03.1-2.mga6
+ Revision: 871203
- Rebuild for boost 1.58.0

* Wed Jun 24 2015 akien <akien> 2015.03.1-1.mga6
+ Revision: 842305
- Requires qscintilla, currently only packaged for Qt4
- Version 2015.03-1

* Wed Oct 15 2014 umeabot <umeabot> 2014.03-3.mga5
+ Revision: 739881
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2014.03-2.mga5
+ Revision: 683239
- Mageia 5 Mass Rebuild

* Mon Sep 08 2014 akien <akien> 2014.03-1.mga5
+ Revision: 673784
- Continue when tests fail on the BS
- Add missing BR on x11-server-xvfb
- Enable test suite building
+ luigiwalser <luigiwalser>
- rebuild for glew

* Thu Jun 12 2014 akien <akien> 2014.03-0.mga5
+ Revision: 635892
- Disable building of the test suite for now
- import source RPM from Fedora


* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2014.03-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri May 23 2014 David Tardon <dtardon@redhat.com> - 2014.03-3
- rebuild for boost 1.55.0

* Thu May 22 2014 Miro Hrončok <mhroncok@redhat.com> - 2014.03-2
- Rebuilt for opencsg 1.3.3

* Sun Mar 09 2014 Miro Hrončok <mhroncok@redhat.com> - 2014.03-1
- New version

* Fri Dec 27 2013 Miro Hrončok <mhroncok@redhat.com> - 2013.06-8
- Enable Xvfb tests
- Add AppData from upstream git

* Mon Nov 18 2013 Dave Airlie <airlied@redhat.com> - 2013.06-7
- rebuilt for GLEW 1.10

* Sun Nov 17 2013 Miro Hrončok <mhroncok@redhat.com> - 2013.06-6
- Rebuilt for new glew

* Fri Sep 27 2013 Miro Hrončok <mhroncok@redhat.com> - 2013.06-5
- Require Python for tests

* Fri Sep 27 2013 Miro Hrončok <mhroncok@redhat.com> - 2013.06-4
- Patch to solve upstream bug #482

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 2013.06-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Sun Jul 28 2013 Petr Machata <pmachata@redhat.com> - 2013.06-2
- Rebuild for boost 1.54.0

* Wed Jun 19 2013 Miro Hrončok <mhroncok@redhat.com> - 2013.06-1
- New upstream release
- Moved removing MCAD to %%install

* Sat Feb 23 2013 Kevin Fenzi <kevin@scrye.com> - 2013.01.17-6
- Rebuild for broken deps in rawhide

* Sun Feb 10 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 2013.01.17-5
- Rebuild for Boost-1.53.0

* Sat Feb 09 2013 Denis Arnaud <denis.arnaud_fedora@m4x.org> - 2013.01.17-4
- Rebuild for Boost-1.53.0

* Sun Feb 03 2013 Miro Hrončok <mhroncok@redhat.com> - 2013.01.17-3
- Added fix for issue 267

* Tue Jan 22 2013 Miro Hrončok <mhroncok@redhat.com> - 2013.01.17-2
- Using  source tarball
- Reffer to the shorter version in the app
- Run tests
- Added patch so test will compile
* Sat Jan 19 2013 Miro Hrončok <mhroncok@redhat.com> - 2013.01.17-1
- New stable release 2013.01
- Updated to respect GitHub rule

* Tue Jan 08 2013 Miro Hrončok <mhroncok@redhat.com> - 2013.01.08-1
- New version

* Sun Jan 06 2013 Miro Hrončok <miro@hroncok.cz> - 2013.01.05-1
- New version

* Thu Dec 06 2012 Miro Hrončok <miro@hroncok.cz> - 2012.10.31-5
- Separated MCAD

* Mon Dec 03 2012 Miro Hrončok <miro@hroncok.cz> - 2012.10.31-4
- Removed useless gziping

* Sun Dec 02 2012 Miro Hrončok <miro@hroncok.cz> - 2012.10.31-3
- Added manpage

* Fri Nov 23 2012 Miro Hrončok <miro@hroncok.cz> - 2012.10.31-2
- Commented macros in comments
- Fully versioned dependency of the main package
- added desktop-file-validate

* Wed Oct 31 2012 Miro Hrončok <miro@hroncok.cz> 2012.10.31-1
- New version
- Solved 2 MLCAD files license issues
- Using full date version

* Mon Oct 08 2012 Miro Hrončok <miro@hroncok.cz> 2012.10-1
- New version.

* Sun Oct 07 2012 Miro Hrončok <miro@hroncok.cz> 2012.08-1
- New package.
